==> org.eclipse.sirius-6.6.1-2020-03.zip: org/eclipse/sirius/tests/swtbot/suite/SequenceSwtBotTestSuite.java <==
/*******************************************************************************
 * Copyright (c) 2010, 2020 THALES GLOBAL SERVICES.
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *    Obeo - initial API and implementation
 *******************************************************************************/
package org.eclipse.sirius.tests.swtbot.suite;

import org.eclipse.sirius.tests.support.api.TestsUtil;
import org.eclipse.sirius.tests.swtbot.Activator;
import org.eclipse.sirius.tests.swtbot.sequence.ActionDisabledOnExtendedMessagesTest;
import org.eclipse.sirius.tests.swtbot.sequence.ActionDisabledOnSequenceDiagramTest;
import org.eclipse.sirius.tests.swtbot.sequence.CombinedFragments2Tests;
import org.eclipse.sirius.tests.swtbot.sequence.CombinedFragmentsAndElementsCreationTests;
import org.eclipse.sirius.tests.swtbot.sequence.CombinedFragmentsAndMessagesCreationTests;
import org.eclipse.sirius.tests.swtbot.sequence.CombinedFragmentsDisabledTests;
import org.eclipse.sirius.tests.swtbot.sequence.CombinedFragmentsMoveTests;
import org.eclipse.sirius.tests.swtbot.sequence.CombinedFragmentsOperandCreationTests;
import org.eclipse.sirius.tests.swtbot.sequence.CombinedFragmentsOperandOverlapTests;
import org.eclipse.sirius.tests.swtbot.sequence.CombinedFragmentsSingleClickCreationTests;
import org.eclipse.sirius.tests.swtbot.sequence.CombinedFragmentsTests;
import org.eclipse.sirius.tests.swtbot.sequence.CombinedFragmentsTwoClickCreationTests;
import org.eclipse.sirius.tests.swtbot.sequence.CombinedFragmentsWithInclusionCreationTests;
import org.eclipse.sirius.tests.swtbot.sequence.ComplexInOutCombinedFragmentTest;
import org.eclipse.sirius.tests.swtbot.sequence.CreateMessageOnCollapsedExecutionTest;
import org.eclipse.sirius.tests.swtbot.sequence.CreateMessageTests;
import org.eclipse.sirius.tests.swtbot.sequence.ExecutionDeletionWithCFChildrenTests;
import org.eclipse.sirius.tests.swtbot.sequence.ExecutionLinkedMessageReconnectionTests;
import org.eclipse.sirius.tests.swtbot.sequence.ExecutionMessageReconnectionTests;
import org.eclipse.sirius.tests.swtbot.sequence.ExecutionMove2Tests;
import org.eclipse.sirius.tests.swtbot.sequence.ExecutionMove3Tests;
import org.eclipse.sirius.tests.swtbot.sequence.ExecutionMove4Tests;
import org.eclipse.sirius.tests.swtbot.sequence.ExecutionMove5Tests;
import org.eclipse.sirius.tests.swtbot.sequence.ExecutionMove6Tests;
import org.eclipse.sirius.tests.swtbot.sequence.ExecutionMoveTests;
import org.eclipse.sirius.tests.swtbot.sequence.ExecutionReconnectionTests;
import org.eclipse.sirius.tests.swtbot.sequence.ExecutionSelectionEditPolicyTests;
import org.eclipse.sirius.tests.swtbot.sequence.ExecutionTests;
import org.eclipse.sirius.tests.swtbot.sequence.ExternalModificationsTests;
import org.eclipse.sirius.tests.swtbot.sequence.FoundLostMessageTests;
import org.eclipse.sirius.tests.swtbot.sequence.FrameMoveWithExpansionTest;
import org.eclipse.sirius.tests.swtbot.sequence.FrameReparentTest;
import org.eclipse.sirius.tests.swtbot.sequence.HeaderSequenceDiagramTests;
import org.eclipse.sirius.tests.swtbot.sequence.InstanceRoleOrderingTests;
import org.eclipse.sirius.tests.swtbot.sequence.InstanceRoleResizableEditPolicyTests;
import org.eclipse.sirius.tests.swtbot.sequence.InteractionUseCoverageTests;
import org.eclipse.sirius.tests.swtbot.sequence.InteractionUseMoveDownTests;
import org.eclipse.sirius.tests.swtbot.sequence.InteractionUseResizeTests;
import org.eclipse.sirius.tests.swtbot.sequence.InteractionUseSingleClickCreationTests;
import org.eclipse.sirius.tests.swtbot.sequence.InteractionUseTests;
import org.eclipse.sirius.tests.swtbot.sequence.InteractionUseTwoClickCreationTests;
import org.eclipse.sirius.tests.swtbot.sequence.MessageExtensionTest;
import org.eclipse.sirius.tests.swtbot.sequence.NonAutoRefreshSequenceExecutionBasicAndReturnMessageTest;
import org.eclipse.sirius.tests.swtbot.sequence.NoteAttachmentTest;
import org.eclipse.sirius.tests.swtbot.sequence.NoteAttachmentsWithCombinedFragmentTests;
import org.eclipse.sirius.tests.swtbot.sequence.ObservationPointTests;
import org.eclipse.sirius.tests.swtbot.sequence.PunctualStateTests;
import org.eclipse.sirius.tests.swtbot.sequence.RefreshLayoutScopeTests;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceArrangeLinkedBorderedNodesTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceBasicMessageTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceDestroyMessageMoveTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceDestroyMessageTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceDiagramDirtyTests;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceDiagramNoSnapTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceExecutionBasicAndReturnMessageTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceExecutionMessageToSelfReparentTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceExecutionMessageToSelfTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceLifelineTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceMessageToSelfTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceOpeningFilteredEventEndsTests;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceReorderTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceReturnMessageTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceSpaceTest;
import org.eclipse.sirius.tests.swtbot.sequence.StateBasicTests;
import org.eclipse.sirius.tests.swtbot.sequence.StateHierarchyTests;
import org.eclipse.sirius.tests.swtbot.sequence.StateNoMessageTests;
import org.eclipse.sirius.tests.swtbot.sequence.SyncCall2Test;
import org.eclipse.sirius.tests.swtbot.sequence.SyncCall3Test;
import org.eclipse.sirius.tests.swtbot.sequence.SyncCallInOperandReorderTest;
import org.eclipse.sirius.tests.swtbot.sequence.SyncCallMoveTest;
import org.eclipse.sirius.tests.swtbot.sequence.SyncCallTest;
import org.eclipse.sirius.tests.unit.common.EnvironmentReportTest;

import junit.framework.JUnit4TestAdapter;
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;
import junit.textui.TestRunner;

/**
 * All SWTBot tests on sequence diagram.
 * 
 * @author smonnier
 */
public class SequenceSwtBotTestSuite extends TestCase {

    /**
     * Launches the test with the given arguments.
     * 
     * @param args
     *            Arguments of the testCase.
     */
    public static void main(final String[] args) {
        TestRunner.run(suite());
    }

    @SuppressWarnings("javadoc")
    public static class SWTBotSequenceBundlesReport extends EnvironmentReportTest {
        public SWTBotSequenceBundlesReport() {
            super(Activator.getDefault().getBundle(), "SWTBot-Sequence");
        }
    }

    /**
     * Add the gerrit part of the Sequence tests to the specified suite.
     * 
     * @param suite
     *            the suite into which to add the tests.
     */
    public static void addGerritPart(TestSuite suite) {
        suite.addTest(new JUnit4TestAdapter(SWTBotSequenceBundlesReport.class));
        suite.addTestSuite(InstanceRoleResizableEditPolicyTests.class);
        suite.addTestSuite(SequenceReorderTest.class);
        suite.addTestSuite(SequenceDiagramDirtyTests.class);
        suite.addTestSuite(SequenceOpeningFilteredEventEndsTests.class);
        if (!(System.getProperty("os.name").contains("Linux") && TestsUtil.is202003Platform())) {
            suite.addTestSuite(SequenceDiagramNoSnapTest.class);
        }
        suite.addTestSuite(FrameMoveWithExpansionTest.class);
        suite.addTestSuite(SequenceLifelineTest.class);
        suite.addTestSuite(SequenceBasicMessageTest.class);
        suite.addTestSuite(MessageExtensionTest.class);
        suite.addTestSuite(SequenceMessageToSelfTest.class);
        suite.addTestSuite(CreateMessageTests.class);
        suite.addTestSuite(ExecutionTests.class);
        suite.addTestSuite(ExecutionMove2Tests.class);
        suite.addTestSuite(ExecutionMove3Tests.class);
        suite.addTestSuite(ExecutionMove4Tests.class);
        suite.addTestSuite(ExecutionMove5Tests.class);
        suite.addTestSuite(ExecutionDeletionWithCFChildrenTests.class);
        suite.addTestSuite(ExecutionReconnectionTests.class);
        suite.addTestSuite(ExecutionMessageReconnectionTests.class);
        suite.addTestSuite(ExecutionLinkedMessageReconnectionTests.class);
        suite.addTestSuite(ExternalModificationsTests.class);
        suite.addTestSuite(FoundLostMessageTests.class);
        suite.addTestSuite(SequenceSpaceTest.class);
        suite.addTestSuite(RefreshLayoutScopeTests.class);
        suite.addTestSuite(InstanceRoleOrderingTests.class);
        // suite.addTestSuite(ContextMenuInDiagramTest.class);
    }

    /**
     * Creates the {@link junit.framework.TestSuite TestSuite} for all the test.<BR>
     * This suite can also launch a specific test by setting the environment variable TEST_CLASS_NAME to the qualified
     * name of the expected class to launch.
     * 
     * @return The test suite containing all the tests
     */
    @SuppressWarnings("unchecked")
    public static Test suite() {
        final TestSuite suite = new TestSuite("SwtBot tests on sequence diagram");

        String testClassQualifiedName = System.getenv("TEST_CLASS_NAME"); //$NON-NLS-1$
        if (testClassQualifiedName != null && testClassQualifiedName.length() > 0) {
            try {
                Class<?> testToLaunch = Activator.getDefault().getBundle().loadClass(testClassQualifiedName);
                if (TestCase.class.isAssignableFrom(testToLaunch)) {
                    suite.addTestSuite((Class<? extends TestCase>) testToLaunch);
                }
            } catch (ClassNotFoundException e) {
                fail("The class " + testClassQualifiedName + ", to launch for test specific case, has not been found.");
            }
        } else {
            addGerritPart(suite);

            suite.addTestSuite(SequenceReturnMessageTest.class);
            suite.addTestSuite(SyncCallTest.class);
            suite.addTestSuite(SyncCallMoveTest.class);
            suite.addTestSuite(SyncCall2Test.class);
            suite.addTestSuite(SyncCall3Test.class);
            suite.addTestSuite(SyncCallInOperandReorderTest.class);
            suite.addTestSuite(CreateMessageOnCollapsedExecutionTest.class);
            suite.addTestSuite(SequenceExecutionMessageToSelfTest.class);
            suite.addTestSuite(SequenceDestroyMessageTest.class);
            suite.addTestSuite(NoteAttachmentTest.class);
            suite.addTestSuite(NoteAttachmentsWithCombinedFragmentTests.class);
            suite.addTestSuite(SequenceArrangeLinkedBorderedNodesTest.class);
            suite.addTestSuite(InteractionUseSingleClickCreationTests.class);
            suite.addTestSuite(InteractionUseTwoClickCreationTests.class);
            suite.addTestSuite(InteractionUseCoverageTests.class);
            suite.addTestSuite(InteractionUseTests.class);
            suite.addTestSuite(InteractionUseMoveDownTests.class);
            suite.addTestSuite(InteractionUseResizeTests.class);
            suite.addTestSuite(CombinedFragmentsSingleClickCreationTests.class);
            suite.addTestSuite(CombinedFragmentsTwoClickCreationTests.class);
            suite.addTestSuite(CombinedFragmentsWithInclusionCreationTests.class);
            suite.addTestSuite(CombinedFragmentsAndElementsCreationTests.class);
            suite.addTestSuite(CombinedFragmentsAndMessagesCreationTests.class);
            suite.addTestSuite(CombinedFragmentsTests.class);
            suite.addTestSuite(CombinedFragmentsOperandCreationTests.class);
            suite.addTestSuite(CombinedFragmentsOperandOverlapTests.class);
            suite.addTestSuite(CombinedFragmentsMoveTests.class);
            suite.addTestSuite(StateBasicTests.class);
            suite.addTestSuite(PunctualStateTests.class);
            suite.addTestSuite(StateNoMessageTests.class);
            suite.addTestSuite(ComplexInOutCombinedFragmentTest.class);
            suite.addTestSuite(ObservationPointTests.class);
            suite.addTestSuite(ActionDisabledOnSequenceDiagramTest.class);
            suite.addTestSuite(ActionDisabledOnExtendedMessagesTest.class);
            suite.addTestSuite(FrameReparentTest.class);
            suite.addTestSuite(HeaderSequenceDiagramTests.class);
            suite.addTestSuite(SequenceExecutionBasicAndReturnMessageTest.class);
            suite.addTestSuite(ExecutionMoveTests.class);
        }
        return suite;
    }

    /**
     * Creates the {@link junit.framework.TestSuite TestSuite} for all the disabled test.
     * 
     * @return The test suite containing all the disabled tests.
     */
    public static Test disabledSuite() {
        final TestSuite suite = new TestSuite("Sequence Disabled SwtBot tests");

        suite.addTestSuite(SequenceDestroyMessageMoveTest.class);
        suite.addTestSuite(SequenceExecutionMessageToSelfReparentTest.class);
        suite.addTestSuite(ExecutionSelectionEditPolicyTests.class);
        suite.addTestSuite(ExecutionMove6Tests.class);

        suite.addTestSuite(StateHierarchyTests.class);

        // Non auto refresh undo redo after delete with reparent/reconnect fails
        suite.addTestSuite(NonAutoRefreshSequenceExecutionBasicAndReturnMessageTest.class);

        suite.addTestSuite(CombinedFragmentsDisabledTests.class);
        suite.addTestSuite(CombinedFragments2Tests.class);
        return suite;
    }

}

==> org.eclipse.sirius-7.4.14-2023-03.zip: org/eclipse/sirius/tests/swtbot/suite/SequenceSwtBotTestSuite.java <==
/*******************************************************************************
 * Copyright (c) 2010, 2025 THALES GLOBAL SERVICES.
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *    Obeo - initial API and implementation
 *******************************************************************************/
package org.eclipse.sirius.tests.swtbot.suite;

import org.eclipse.sirius.tests.support.api.TestsUtil;
import org.eclipse.sirius.tests.swtbot.Activator;
import org.eclipse.sirius.tests.swtbot.sequence.ActionDisabledOnExtendedMessagesTest;
import org.eclipse.sirius.tests.swtbot.sequence.ActionDisabledOnSequenceDiagramTest;
import org.eclipse.sirius.tests.swtbot.sequence.CombinedFragments2Tests;
import org.eclipse.sirius.tests.swtbot.sequence.CombinedFragmentsAndElementsCreationTests;
import org.eclipse.sirius.tests.swtbot.sequence.CombinedFragmentsAndMessagesCreationTests;
import org.eclipse.sirius.tests.swtbot.sequence.CombinedFragmentsDisabledTests;
import org.eclipse.sirius.tests.swtbot.sequence.CombinedFragmentsOperandCreationTests;
import org.eclipse.sirius.tests.swtbot.sequence.CombinedFragmentsOperandOverlapTests;
import org.eclipse.sirius.tests.swtbot.sequence.CombinedFragmentsSingleClickCreationTests;
import org.eclipse.sirius.tests.swtbot.sequence.CombinedFragmentsTests;
import org.eclipse.sirius.tests.swtbot.sequence.CombinedFragmentsTwoClickCreationTests;
import org.eclipse.sirius.tests.swtbot.sequence.CombinedFragmentsWithInclusionCreationTests;
import org.eclipse.sirius.tests.swtbot.sequence.ComplexInOutCombinedFragmentTest;
import org.eclipse.sirius.tests.swtbot.sequence.CreateMessageOnCollapsedExecutionTest;
import org.eclipse.sirius.tests.swtbot.sequence.CreateMessageTests;
import org.eclipse.sirius.tests.swtbot.sequence.ExecutionDeletionWithCFChildrenTests;
import org.eclipse.sirius.tests.swtbot.sequence.ExecutionLinkedMessageReconnectionTests;
import org.eclipse.sirius.tests.swtbot.sequence.ExecutionMessageReconnectionTests;
import org.eclipse.sirius.tests.swtbot.sequence.ExecutionMove2Tests;
import org.eclipse.sirius.tests.swtbot.sequence.ExecutionMove3Tests;
import org.eclipse.sirius.tests.swtbot.sequence.ExecutionMove4Tests;
import org.eclipse.sirius.tests.swtbot.sequence.ExecutionMove5Tests;
import org.eclipse.sirius.tests.swtbot.sequence.ExecutionMove6Tests;
import org.eclipse.sirius.tests.swtbot.sequence.ExecutionMoveTests;
import org.eclipse.sirius.tests.swtbot.sequence.ExecutionReconnectionTests;
import org.eclipse.sirius.tests.swtbot.sequence.ExecutionSelectionEditPolicyTests;
import org.eclipse.sirius.tests.swtbot.sequence.ExecutionTests;
import org.eclipse.sirius.tests.swtbot.sequence.ExternalModificationsTests;
import org.eclipse.sirius.tests.swtbot.sequence.FoundLostMessageTests;
import org.eclipse.sirius.tests.swtbot.sequence.FrameMoveWithExpansionTest;
import org.eclipse.sirius.tests.swtbot.sequence.FrameReparentTest;
import org.eclipse.sirius.tests.swtbot.sequence.GatesTests;
import org.eclipse.sirius.tests.swtbot.sequence.HeaderSequenceDiagramTests;
import org.eclipse.sirius.tests.swtbot.sequence.InstanceRoleOrderingTests;
import org.eclipse.sirius.tests.swtbot.sequence.InstanceRoleResizableEditPolicyTests;
import org.eclipse.sirius.tests.swtbot.sequence.InteractionUseCoverageTests;
import org.eclipse.sirius.tests.swtbot.sequence.InteractionUseMoveDownTests;
import org.eclipse.sirius.tests.swtbot.sequence.InteractionUseResizeTests;
import org.eclipse.sirius.tests.swtbot.sequence.InteractionUseSingleClickCreationTests;
import org.eclipse.sirius.tests.swtbot.sequence.InteractionUseTests;
import org.eclipse.sirius.tests.swtbot.sequence.InteractionUseTwoClickCreationTests;
import org.eclipse.sirius.tests.swtbot.sequence.MessageExtensionTest;
import org.eclipse.sirius.tests.swtbot.sequence.NonAutoRefreshSequenceExecutionBasicAndReturnMessageTest;
import org.eclipse.sirius.tests.swtbot.sequence.NoteAttachmentTest;
import org.eclipse.sirius.tests.swtbot.sequence.NoteAttachmentsWithCombinedFragmentTests;
import org.eclipse.sirius.tests.swtbot.sequence.ObliqueMessagesTests;
import org.eclipse.sirius.tests.swtbot.sequence.ObservationPointTests;
import org.eclipse.sirius.tests.swtbot.sequence.PunctualStateTests;
import org.eclipse.sirius.tests.swtbot.sequence.RefreshLayoutScopeTests;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceArrangeLinkedBorderedNodesTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceBasicMessageTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceDestroyMessageMoveTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceDestroyMessageTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceDiagramDirtyTests;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceDiagramNoSnapTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceExecutionBasicAndReturnMessageObervationPointDisplayedTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceExecutionBasicAndReturnMessageTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceExecutionMessageToSelfReparentTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceExecutionMessageToSelfTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceLifelineTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceMessageToSelfTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceOpeningFilteredEventEndsTests;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceReorderTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceReturnMessageTest;
import org.eclipse.sirius.tests.swtbot.sequence.SequenceSpaceTest;
import org.eclipse.sirius.tests.swtbot.sequence.StateBasicTests;
import org.eclipse.sirius.tests.swtbot.sequence.StateHierarchyTests;
import org.eclipse.sirius.tests.swtbot.sequence.StateNoMessageTests;
import org.eclipse.sirius.tests.swtbot.sequence.SyncCall2Test;
import org.eclipse.sirius.tests.swtbot.sequence.SyncCall3Test;
import org.eclipse.sirius.tests.swtbot.sequence.SyncCallInOperandReorderTest;
import org.eclipse.sirius.tests.swtbot.sequence.SyncCallMoveTest;
import org.eclipse.sirius.tests.swtbot.sequence.SyncCallTest;
import org.eclipse.sirius.tests.swtbot.sequence.TwoSessionsTests;
import org.eclipse.sirius.tests.unit.common.EnvironmentReportTest;

import junit.framework.JUnit4TestAdapter;
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;
import junit.textui.TestRunner;

/**
 * All SWTBot tests on sequence diagram.
 * 
 * @author smonnier
 */
public class SequenceSwtBotTestSuite extends TestCase {

    /**
     * Launches the test with the given arguments.
     * 
     * @param args
     *            Arguments of the testCase.
     */
    public static void main(final String[] args) {
        TestRunner.run(suite());
    }

    @SuppressWarnings("javadoc")
    public static class SWTBotSequenceBundlesReport extends EnvironmentReportTest {
        public SWTBotSequenceBundlesReport() {
            super(Activator.getDefault().getBundle(), "SWTBot-Sequence");
        }
    }

    /**
     * Add the gerrit part of the Sequence tests to the specified suite.
     * 
     * @param suite
     *            the suite into which to add the tests.
     */
    public static void addGerritPart(TestSuite suite) {
        suite.addTest(new JUnit4TestAdapter(SWTBotSequenceBundlesReport.class));
        suite.addTestSuite(InstanceRoleResizableEditPolicyTests.class);
        suite.addTestSuite(SequenceReorderTest.class);
        suite.addTestSuite(SequenceDiagramDirtyTests.class);
        suite.addTestSuite(SequenceOpeningFilteredEventEndsTests.class);
        if (!(System.getProperty("os.name").contains("Linux") && TestsUtil.is202003Platform())) {
            suite.addTestSuite(SequenceDiagramNoSnapTest.class);
        }
        suite.addTestSuite(FrameMoveWithExpansionTest.class);
        suite.addTestSuite(SequenceLifelineTest.class);
        suite.addTestSuite(MessageExtensionTest.class);
        suite.addTestSuite(CreateMessageTests.class);
        suite.addTestSuite(ExecutionTests.class);
        suite.addTestSuite(ExecutionMove2Tests.class);
        suite.addTestSuite(ExecutionMove3Tests.class);
        suite.addTestSuite(ExecutionMove4Tests.class);
        suite.addTestSuite(ExecutionMove5Tests.class);
        suite.addTestSuite(ExecutionDeletionWithCFChildrenTests.class);
        suite.addTestSuite(ExecutionReconnectionTests.class);
        suite.addTestSuite(ExecutionMessageReconnectionTests.class);
        suite.addTestSuite(ExternalModificationsTests.class);
        suite.addTestSuite(FoundLostMessageTests.class);
        suite.addTestSuite(SequenceSpaceTest.class);
        suite.addTestSuite(RefreshLayoutScopeTests.class);
        suite.addTestSuite(InstanceRoleOrderingTests.class);
        // suite.addTestSuite(InteractionContainerTests.class);
        // suite.addTestSuite(ContextMenuInDiagramTest.class);
        suite.addTestSuite(GatesTests.class);
        suite.addTestSuite(ObliqueMessagesTests.class);
    }

    /**
     * Creates the {@link junit.framework.TestSuite TestSuite} for all the test.<BR>
     * This suite can also launch a specific test by setting the environment variable TEST_CLASS_NAME to the qualified
     * name of the expected class to launch.
     * 
     * @return The test suite containing all the tests
     */
    @SuppressWarnings("unchecked")
    public static Test suite() {
        final TestSuite suite = new TestSuite("SwtBot tests on sequence diagram");

        String testClassQualifiedName = System.getenv("TEST_CLASS_NAME"); //$NON-NLS-1$
        if (testClassQualifiedName != null && testClassQualifiedName.length() > 0) {
            try {
                Class<?> testToLaunch = Activator.getDefault().getBundle().loadClass(testClassQualifiedName);
                if (TestCase.class.isAssignableFrom(testToLaunch)) {
                    suite.addTestSuite((Class<? extends TestCase>) testToLaunch);
                }
            } catch (ClassNotFoundException e) {
                fail("The class " + testClassQualifiedName + ", to launch for test specific case, has not been found.");
            }
        } else {
            addGerritPart(suite);

            suite.addTestSuite(SequenceBasicMessageTest.class);
            suite.addTestSuite(SequenceMessageToSelfTest.class);
            suite.addTestSuite(ExecutionLinkedMessageReconnectionTests.class);
            suite.addTestSuite(SequenceReturnMessageTest.class);
            suite.addTestSuite(SyncCallTest.class);
            suite.addTestSuite(SyncCallMoveTest.class);
            suite.addTestSuite(SyncCall2Test.class);
            suite.addTestSuite(SyncCall3Test.class);
            suite.addTestSuite(SyncCallInOperandReorderTest.class);
            suite.addTestSuite(CreateMessageOnCollapsedExecutionTest.class);
            suite.addTestSuite(SequenceExecutionMessageToSelfTest.class);
            suite.addTestSuite(SequenceDestroyMessageTest.class);
            suite.addTestSuite(NoteAttachmentTest.class);
            suite.addTestSuite(NoteAttachmentsWithCombinedFragmentTests.class);
            suite.addTestSuite(SequenceArrangeLinkedBorderedNodesTest.class);
            suite.addTestSuite(InteractionUseSingleClickCreationTests.class);
            suite.addTestSuite(InteractionUseTwoClickCreationTests.class);
            suite.addTestSuite(InteractionUseCoverageTests.class);
            suite.addTestSuite(InteractionUseTests.class);
            suite.addTestSuite(InteractionUseMoveDownTests.class);
            suite.addTestSuite(InteractionUseResizeTests.class);
            suite.addTestSuite(CombinedFragmentsSingleClickCreationTests.class);
            suite.addTestSuite(CombinedFragmentsTwoClickCreationTests.class);
            suite.addTestSuite(CombinedFragmentsWithInclusionCreationTests.class);
            suite.addTestSuite(CombinedFragmentsAndElementsCreationTests.class);
            suite.addTestSuite(CombinedFragmentsAndMessagesCreationTests.class);
            suite.addTestSuite(CombinedFragmentsTests.class);
            suite.addTestSuite(CombinedFragmentsOperandCreationTests.class);
            suite.addTestSuite(CombinedFragmentsOperandOverlapTests.class);
            suite.addTestSuite(StateBasicTests.class);
            suite.addTestSuite(PunctualStateTests.class);
            suite.addTestSuite(StateNoMessageTests.class);
            suite.addTestSuite(ComplexInOutCombinedFragmentTest.class);
            suite.addTestSuite(ObservationPointTests.class);
            suite.addTestSuite(ActionDisabledOnSequenceDiagramTest.class);
            suite.addTestSuite(ActionDisabledOnExtendedMessagesTest.class);
            suite.addTestSuite(FrameReparentTest.class);
            suite.addTestSuite(HeaderSequenceDiagramTests.class);
            suite.addTestSuite(SequenceExecutionBasicAndReturnMessageTest.class);
            suite.addTestSuite(SequenceExecutionBasicAndReturnMessageObervationPointDisplayedTest.class);
            suite.addTestSuite(ExecutionMoveTests.class);
            suite.addTestSuite(TwoSessionsTests.class);
        }
        return suite;
    }

    /**
     * Creates the {@link junit.framework.TestSuite TestSuite} for all the disabled test.
     * 
     * @return The test suite containing all the disabled tests.
     */
    public static Test disabledSuite() {
        final TestSuite suite = new TestSuite("Sequence Disabled SwtBot tests");

        suite.addTestSuite(SequenceDestroyMessageMoveTest.class);
        suite.addTestSuite(SequenceExecutionMessageToSelfReparentTest.class);
        suite.addTestSuite(ExecutionSelectionEditPolicyTests.class);
        suite.addTestSuite(ExecutionMove6Tests.class);

        suite.addTestSuite(StateHierarchyTests.class);

        // Non auto refresh undo redo after delete with reparent/reconnect fails
        suite.addTestSuite(NonAutoRefreshSequenceExecutionBasicAndReturnMessageTest.class);

        suite.addTestSuite(CombinedFragmentsDisabledTests.class);
        suite.addTestSuite(CombinedFragments2Tests.class);
        return suite;
    }

}
